import {HttpException, HttpStatus, Injectable} from "@nestjs/common";
import {InjectRepository} from "@nestjs/typeorm";
import {Constants} from "src/utils/constants";
import {ResponseUtils} from "src/utils/response.utils";
import {UploadedMulterFileI} from "src/modules/SpacesModule/SpacesService";
import {DoSpacesService} from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { AboutPageSectionOneCmsRepository } from "./about-page-section-one-cms.repository";
import { UpdateAboutPageSectionOneCmsDto } from "./dto/update-about-page-section-one-cms.dto";
import { AboutPageSectionOneCmsEntity } from "./entities/about-page-section-one-cms.entity";

@Injectable()
export class AboutPageSectionOneCmsService {
    constructor(
        @InjectRepository(AboutPageSectionOneCmsRepository)
        private readonly repository: AboutPageSectionOneCmsRepository,
        private readonly doSpaceService: DoSpacesService
    ) {
    }

    async updateOrCreateData(
        dto: UpdateAboutPageSectionOneCmsDto,
        files: {
            imageOne: UploadedMulterFileI,
            imageTwo: UploadedMulterFileI
        }
    ): Promise<AboutPageSectionOneCmsEntity | Error> {
        if (files && files.imageOne) {
            const imageOne: any = await this.doSpaceService.uploadFile(files.imageOne[0], "AboutPageSectionOneCms/");
            dto.imageOne = imageOne;
        }
        if (files && files.imageTwo) {
            const imageTwo: any = await this.doSpaceService.uploadFile(files.imageTwo[0], "AboutPageSectionOneCms/");
            dto.imageTwo = imageTwo;
        }
        const isExists = await this.repository.find({isDeleted: false});
        if (Object.keys(isExists).length === 0) {
            const data = await this.repository.createEntity(dto);
            if (!data) {
                throw new HttpException(
                    Constants.NOT_FOUND,
                    HttpStatus.NOT_FOUND
                );
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            let id = isExists[0].id;
            const data = await this.repository.updateEntity(dto, id);
            if (!data) {
                throw new HttpException(
                    Constants.UPDATE_FAILED,
                    HttpStatus.BAD_REQUEST
                );
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<AboutPageSectionOneCmsEntity[] | Error> {
        const data = await this.repository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}