import {HttpException, HttpStatus, Injectable} from "@nestjs/common";
import {InjectRepository} from "@nestjs/typeorm";
import {Constants} from "src/utils/constants";
import {ResponseUtils} from "src/utils/response.utils";
import {UploadedMulterFileI} from "src/modules/SpacesModule/SpacesService";
import {DoSpacesService} from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { AboutPageSectionTwoCmsRepository } from "./about-page-section-two-cms.repository";
import { UpdateAboutPageSectionTwoCmsDto } from "./dto/update-about-page-section-two-cms.dto";
import { AboutPageSectionTwoCmsEntity } from "./entities/about-page-section-two-cms.entity";

@Injectable()
export class AboutPageSectionTwoCmsService {
    constructor(
        @InjectRepository(AboutPageSectionTwoCmsRepository)
        private readonly repository: AboutPageSectionTwoCmsRepository,
        private readonly doSpaceService: DoSpacesService
    ) {
    }

    async updateOrCreateData(
        dto: UpdateAboutPageSectionTwoCmsDto,
        files: {
            image: UploadedMulterFileI
        }
    ): Promise<AboutPageSectionTwoCmsEntity | Error> {
        if (files && files.image) {
            const image: any = await this.doSpaceService.uploadFile(files.image[0], "AboutPageSectionTwoCms/");
            dto.image = image;
        }
        const isExists = await this.repository.find({isDeleted: false});
        if (Object.keys(isExists).length === 0) {
            const data = await this.repository.createEntity(dto);
            if (!data) {
                throw new HttpException(
                    Constants.NOT_FOUND,
                    HttpStatus.NOT_FOUND
                );
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            let id = isExists[0].id;
            const data = await this.repository.updateEntity(dto, id);
            if (!data) {
                throw new HttpException(
                    Constants.UPDATE_FAILED,
                    HttpStatus.BAD_REQUEST
                );
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<AboutPageSectionTwoCmsEntity[] | Error> {
        const data = await this.repository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}