import {
    Body,
    Controller,
    Get,
    HttpCode,
    HttpStatus,
    Post,
    UploadedFiles,
    UseGuards,
    UseInterceptors
} from "@nestjs/common";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";
import { Constants } from "src/utils/constants";
import { FileFieldsInterceptor } from "@nestjs/platform-express";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { UpdateHomePageBannerSectionCmsDto } from "./dto/update-home-page-banner-section-cms.dto";
import { HomePageBannerSectionCmsService } from "./home-page-banner-section-cms.service";

@Controller({ path: "home-page-banner-section-cms", version: Constants.API_VERSION_1 })

export class HomePageBannerSectionCmsController {
    constructor(private readonly service: HomePageBannerSectionCmsService) { }

    @Post()
    @HttpCode(HttpStatus.OK)
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
        [
            { name: "image", maxCount: 1 },
            { name: "backgroundImage", maxCount: 1 }
        ]
    ))
    updateOrCreateData(
        @Body() dto: UpdateHomePageBannerSectionCmsDto,
        @UploadedFiles() files: {
            image: UploadedMulterFileI,
            backgroundImage: UploadedMulterFileI
        }
    ) {
        return this.service.updateOrCreateData(dto, files);
    }

    @Get()
    // @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }
}
