import { HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectRepository } from "@nestjs/typeorm";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { RegistrationPageCmsRepository } from "./registration-page-cms.repository";
import { UpdateRegistrationPageCmsDto } from "./dto/update-registration-page-cms.dto";
import { RegistrationPageCmsEntity } from "./entities/registration-page-cms.entity";

@Injectable()
export class RegistrationPageCmsService {
    constructor(
        @InjectRepository(RegistrationPageCmsRepository)
        private readonly repository: RegistrationPageCmsRepository,
        private readonly doSpaceService: DoSpacesService
    ) {
    }

    async updateOrCreateData(
        dto: UpdateRegistrationPageCmsDto,
        files: {
            image: UploadedMulterFileI
        }
    ): Promise<RegistrationPageCmsEntity | Error> {
        if (files && files.image) {
            const image: any = await this.doSpaceService.uploadFile(files.image[0], "RegistrationPageCms/");
            dto.image = image;
        }
        const isExists = await this.repository.find({ isDeleted: false });
        if (Object.keys(isExists).length === 0) {
            const data = await this.repository.createEntity(dto);
            if (!data) {
                throw new HttpException(
                    Constants.NOT_FOUND,
                    HttpStatus.NOT_FOUND
                );
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            let id = isExists[0].id;
            const data = await this.repository.updateEntity(dto, id);
            if (!data) {
                throw new HttpException(
                    Constants.UPDATE_FAILED,
                    HttpStatus.BAD_REQUEST
                );
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<RegistrationPageCmsEntity[] | Error> {
        const data = await this.repository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}