import { HttpException, HttpStatus, Injectable } from '@nestjs/common';
import { InjectRepository } from '@nestjs/typeorm';
import { FileUploadsService } from 'src/modules/file-uploads/file-uploads.service';
import { Constants } from 'src/utils/constants';
import { ResponseUtils } from 'src/utils/response.utils';
import { CreateShippingMethodCMSDto } from './dto/create-shipping-method-cms-dto.dto';
import { ShippingMethodCMS } from './entities/shipping-method-cms.entity';
import { ShippingMethodCMSRepository } from './shipping-method-cms.repository';
import { DoSpacesService } from '../../SpacesModule/SpacesService/doSpacesService';

@Injectable()
export class ShippingMethodCMSService {
    constructor(
        @InjectRepository(ShippingMethodCMSRepository)
        private readonly repository: ShippingMethodCMSRepository,
        private readonly fileService: FileUploadsService,
        private readonly doSpaceService: DoSpacesService
    ) {
    }

    async updateOrCreateData(
        dto: CreateShippingMethodCMSDto,
        files: {
            upsImage?: Express.Multer.File
        }
    ): Promise<ShippingMethodCMS | Error> {
        if (files && files.upsImage) {
            const upsImage: any = await this.doSpaceService.uploadFile(files.upsImage[0], "ShippingMethods/");
            dto.upsImage = upsImage;
        }
        const isExists = await this.repository.find();
        if (Object.keys(isExists).length === 0) {
            const data = await this.repository.createEntity(dto);
            if (!data) {
                throw new HttpException(
                    Constants.GENERIC_ERROR,
                    HttpStatus.FORBIDDEN
                );
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully", "data", data);
        } else {
            let id = isExists[0].id;
            const data = await this.repository.updateEntity(dto, id);
            if (!data) {
                throw new HttpException(
                    Constants.UPDATE_FAILED,
                    HttpStatus.FORBIDDEN
                );
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully", "data", data);
        }
    }

    async findAll(): Promise<ShippingMethodCMS[] | Error> {
        const data = await this.repository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}
