import { EntityRepository, getConnection, Repository } from "typeorm";
import { HomePageAboutSectionEntity } from "./entities/home-page-about-section.entity";
import { CreateHomePageAboutSectionDto } from "./dto/create-home-page-about-section.dto";
import { UpdateHomePageAboutSectionDto } from "./dto/update-home-page-about-section.dto";

@EntityRepository(HomePageAboutSectionEntity)
export class HomePageAboutSectionRepository extends Repository<HomePageAboutSectionEntity> {
    async createEntity(dto: CreateHomePageAboutSectionDto): Promise<HomePageAboutSectionEntity | Error> {
        try {
            const {
                text,
            } = dto;
            const entity = this.create({
                text
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<HomePageAboutSectionEntity | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateHomePageAboutSectionDto): Promise<HomePageAboutSectionEntity | Error> {
        try {
            await this.update(id, {
                text: dto.text,
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<HomePageAboutSectionEntity[] | Error> {
        try {
            return await this.find({
                where: { ...query, isDeleted: false }
            });
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(HomePageAboutSectionEntity)
                .set({ isDeleted: true })
                .where("id = :id", { id: id })
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }
}