import {EntityRepository, getConnection, Repository} from "typeorm";
import { StripeEntity } from "./entity/stripe.entity";
import { CreateStripeDto } from "./dto/create-stripe.dto";
import { UpdateStripeDto } from "./dto/update-stripe.dto";


@EntityRepository(StripeEntity)
export class StripeRepository extends Repository<StripeEntity> {
    async createEntity(
        dto: CreateStripeDto
    ): Promise<StripeEntity | Error> {
        try {
            const { stripeData, sessionID, paymentStatus} = dto;
            const entity = this.create({
                stripeData: JSON.stringify(stripeData),
                sessionID,
                paymentStatus
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(
        id: string
    ): Promise<StripeEntity | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async updateEntity(
        id: string,
        dto: UpdateStripeDto
    ): Promise<StripeEntity | Error> {
        try {
            await this.update(id, {
                stripeData: dto.stripeData,
                sessionID: dto.sessionID,
                paymentStatus: dto.paymentStatus
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<StripeEntity[] | Error> {
        try {
            return await this.find({
                where: {...query, isDeleted: false}
            });
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(StripeEntity)
                .set({isDeleted: true})
                .where("id = :id", {id: id})
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }
}