import { EntityRepository, getConnection, Repository } from "typeorm";
import { CreateColorDto } from "./dto/create-color.dto";
import { UpdateColorDto } from "./dto/update-color.dto";
import { Color } from "./entity/color.entity";


@EntityRepository(Color)
export class ColorsRepository extends Repository<Color> {

    async createEntity(
        dto: CreateColorDto
    ): Promise<Color | Error> {
        try {
            const { colorName, colorCode } = dto;
            const entity = this.create({
                colorName,
                colorCode
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findByColorName(colorName: string): Promise<any | Error> {
        try {
            return await this.find({
                where: { colorName: colorName, isDeleted: false }
            });
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<Color[] | Error> {
        try {
            return await this.find({
                where: { ...query, isDeleted: false }
            });
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(
        id: string
    ): Promise<Color | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }


    async updateColor(
        id: string,
        dto: UpdateColorDto
    ): Promise<Color | Error> {
        try {
            await this.update(id, dto);
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(Color)
                .set({ isDeleted: true })
                .where("id = :id", { id: id })
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }

    async findOneByColorName(colorName: string): Promise<any | Error> {
        try {
            return await this.findOne({
                where: { colorName: colorName, isDeleted: false }
            });
        } catch (e) {
            return e;
        }
    }

}