import { Body, Controller, Delete, Get, Param, Patch, Post } from "@nestjs/common";
import { Constants } from "src/utils/constants";
import { ProductReviewService } from "./product-review.service";
import { CreateProductReviewDto } from "./dto/create-product-review.dto";
import { UpdateProductReviewDto } from "./dto/update-product-review.dto";

@Controller({ path: "product-review", version: Constants.API_VERSION_1 })

export class ProductReviewController {
    constructor(private readonly service: ProductReviewService) {}

    @Post()
    create(
        @Body() dto: CreateProductReviewDto
    ) {
        return this.service.create(dto);
    }

    @Get()
    findAll() {
        return this.service.findAll();
    }

    @Get(":id")
    findOne(@Param("id") id: string) {
        return this.service.findOne(id);
    }

    @Patch(':id')
    update(@Param('id') id: string, @Body() dto: UpdateProductReviewDto) {
        return this.service.update(id, dto);
    }

    @Delete(":id")
    async remove(@Param("id") id: string) {
        return await this.service.remove(id);
    }
}
